@@ -67,3 +67,5 @@ from device_class import *
 from globals import *
 from utils import *
 from tango_numpy import *
+from exception import *
+from encoded_attribute import *
\ No newline at end of file
