@@ -65,15 +65,15 @@ class DeviceClassCompleter(object):
 # using may be different than the default TANGO_HOST. What we do is always append
 # the name of the database in usage to the device name given by the user (in case 
 # he doesn't give a database name him(her)self, of course.
-__DeviceProxy_init_orig__ = PyTango.DeviceProxy.__init__
-def __DeviceProxy__init__(self, dev_name):
-    db = __get_db()
-    if db is None: return
-    if dev_name.count(":") == 0:
-        db_name = "%s:%s" % (db.get_db_host(), db.get_db_port())
-        dev_name = "%s/%s" % (db_name, dev_name)
-    __DeviceProxy_init_orig__(self, dev_name)
-PyTango.DeviceProxy.__init__ = __DeviceProxy__init__
+#__DeviceProxy_init_orig__ = PyTango.DeviceProxy.__init__
+#def __DeviceProxy__init__(self, dev_name):
+#    db = __get_db()
+#    if db is None: return
+#    if dev_name.count(":") == 0:
+#        db_name = "%s:%s" % (db.get_db_host(), db.get_db_port())
+#        dev_name = "%s/%s" % (db_name, dev_name)
+#    __DeviceProxy_init_orig__(self, dev_name)
+#PyTango.DeviceProxy.__init__ = __DeviceProxy__init__
 
 #-------------------------------------------------------------------------------
 # Completers
@@ -782,6 +782,8 @@ def init_db(ip, parameter_s=''):
         
     if db is None: return
     
+    os.environ["TANGO_HOST"] = "%s:%s" % (db.get_db_host(), db.get_db_port())
+    
     # Initialize device and server information
     query = "SELECT name, alias, server, class FROM device order by name"
     
@@ -899,7 +901,7 @@ def init_console(ip):
     o = ip.options
 
     so = IPython.ipstruct.Struct(
-        spock_banner = """{Blue}hint: Try typing: mydev = Device("{LightBlue}<tab>{Normal}\n""")
+        spock_banner = """%(Blue)shint: Try typing: mydev = Device("%(LightBlue)s<tab>%(Normal)s\n""")
 
     so = ip.user_ns.get("spock_options", so)
     
@@ -907,15 +909,17 @@ def init_console(ip):
     o.prompt_in1 = "Spock <$DB_NAME> [\\#]: "
     o.prompt_out = "Result [\\#]: "
     banner = """
-{LightPurple}Spock {version}{Normal} -- An interactive {Purple}Tango{Normal} client.
+%(Purple)sSpock %(version)s%(Normal)s -- An interactive %(Purple)sTango%(Normal)s client.
 
-Running on top of Python {pyver}, IPython {ipyver} and PyTango {pytangover}
+Running on top of Python %(pyver)s, IPython %(ipyver)s and PyTango %(pytangover)s
 
 help      -> Spock's help system.
 object?   -> Details about 'object'. ?object also works, ?? prints more.
 
 """ + so.spock_banner
-    o.banner = banner.format(**d)
+    o.banner = banner % d
+    if hasattr(o.banner, "format"):
+        o.banner = o.banner.format(**d)
     
 def init_magic(ip):
     __expose_magic(ip, "refreshdb", magic_refreshdb)
