@@ -7,12 +7,9 @@
 class CppDeviceClass: public Tango::DeviceClass
 {
 public:
-    CppDeviceClass(const string &name)
-        :Tango::DeviceClass(const_cast<string&>(name))
-    {}
+    CppDeviceClass(const string &);
 
-    virtual ~CppDeviceClass()
-    {}
+    virtual ~CppDeviceClass();
 
     /**
      * Export a device.
@@ -68,7 +65,7 @@ public:
                           const std::string &read_method_name,
                           const std::string &write_method_name,
                           const std::string &is_allowed_name,
-                          Tango::UserDefaultAttrProp &att_prop);
+                          Tango::UserDefaultAttrProp *att_prop);
 
     /**
      * Creates a command.
@@ -101,17 +98,12 @@ public:
      * @param[in] self A reference to the python device class object
      * @param[in] name the class name
      */
-    CppDeviceClassWrap(PyObject *self, const std::string &name)
-        : CppDeviceClass(name), m_self(self)
-    {
-        init_class();
-    }
+    CppDeviceClassWrap(PyObject *self, const std::string &name);
 
     /**
      * Destructor
      */
-    virtual ~CppDeviceClassWrap()
-    {}
+    virtual ~CppDeviceClassWrap();
 
     /**
      * This method forward a C++ call to the device_factory method to the
