@@ -535,7 +535,7 @@ void export_wattribute()
             (PyObject* (*) (Tango::WAttribute &))
             &PyWAttribute::get_max_value)
         .def("set_min_value", &PyWAttribute::set_min_value)
-        .def("set_max_value", &PyWAttribute::set_min_value)
+        .def("set_max_value", &PyWAttribute::set_max_value)
         .def("is_min_value", &Tango::WAttribute::is_min_value)
         .def("is_max_value", &Tango::WAttribute::is_max_value)
         .def("get_write_value_length", &Tango::WAttribute::get_write_value_length)
